@@ -10,9 +10,9 @@ def parse_args():
     parser.add_argument('--url', type=str, default='http://www.google.com',
                         dest='url',
                         help='Specifies the url to which send the requests')
-    parser.add_argument('--delay', nargs=1, type=float, default=3, dest='delay',
+    parser.add_argument('--delay', type=float, default=3, dest='delay',
                         help='Specifies the delay to use')
-    parser.add_argument('--num-reqs', nargs=1, type=int, default=5, dest='n_reqs',
+    parser.add_argument('--num-reqs', type=int, default=5, dest='n_reqs',
                         help='Specifies the number of requests to send')
     args = parser.parse_args()
     return {'url': args.url, 'delay': args.delay, 'n_reqs': args.n_reqs}
